@@ -13,6 +13,7 @@ from artify import syncrepo
 from artify import change_version
 from artify import generate_file
 from artify import extract_commands
+from artify import initialize
 
 debug = 0;
 
@@ -38,6 +39,7 @@ password = ''
 directory = ''
 group_id = ''
 auth = ''
+
 # Variables - Nexus
 
 # Variables - Deploy AWX
@@ -60,6 +62,13 @@ commit_message = ''
 filename_gen = ''
 # Variables - create file
 
+# Variables - Initialize
+sonarhost = ''
+language = ''
+project_key = ''
+project_name = ''
+# Variables - Initialize
+
 def main(argv):  
     print("Copyright \N{COPYRIGHT SIGN} 2020 Stewartium ::: artify v{}\n".format(__version__))
     action = ''
@@ -98,14 +107,22 @@ def main(argv):
     
     # Variables - generate file
     global filename_gen
+    
+    # Variables - Initialize
+    global sonarhost
+    global language
+    global project_key
+    global project_name
+    # Variables - Initialize
    
     try:
-        opts, args = getopt.getopt(argv, "a:b:c:d:h:f:m:n:u:p:r:g:t:w:", ["command=", "help=", 
+        opts, args = getopt.getopt(argv, "a:b:c:d:f:h:k:l:m:n:u:p:r:g:t:w:", ["command=", "help=", 
                                                 "artifactname=", "repository=","groupid=", "directory=", "nexushost=",
-                                                "file=", "awxhost=",
+                                                "file=", "awxhost=","--host=",
                                                 "format=",
                                                 "type=", "archtype=", "prevalue=",
                                                 "message=", "branch=",
+                                                "projectkey=", "projectname="
                                                 "debug"
                                                ])
     except getopt.GetoptError:
@@ -149,7 +166,8 @@ def main(argv):
                 print("Mandatory arguments: ")
                 print("-m, --message     Commit message")
                 print("\nOptional arguments: ")
-                print("-h, --host        Repository url")
+                #print("-h, --host        Repository url")
+                print("-b, --branch     Repository branch to sync changes")
                 print("\n--proxy             Sets Http proxy")
                 print("--proxysec          Sets Https proxy")
                 return sys.exit(0)
@@ -182,6 +200,11 @@ def main(argv):
                 print('Sample commit messages below: \n')
                 print("Added login functionality {\"version\": \"patch\", \"archtype\": \"npm\", \"branch\": \"release\" } \n")
                 print("Added edit functionality {\"version\": \"minor\", \"a\": \"flutter\" } \n")
+            elif arg == 'initialize':
+                print('')
+                print('python -m artify -c initialize -h <SonarQube_base_url> -u <username> -p <password> -a <arch_type/os> -l <language>')    
+                print('\nExample below for a java project that uses gradle build tool.')
+                print('\npython -m artify -c initialize -h <SonarQube_base_url> -u <username> -p <password> -l java -a gradle\n')
             else:
                 print('python -m artify --help nexus        Help on how to deploy to Nexus Repository')
                 print('python -m artify --help deploy       Help on how to deploy to AWX host')
@@ -230,7 +253,7 @@ def main(argv):
         ## Change-version-number params START
         elif opt in ("-t", "--type"):
             change_type = arg
-            
+             
         elif opt in ("-a", "--archtype"):
             arch_type = arg 
             
@@ -241,7 +264,7 @@ def main(argv):
         
         ## Deploy-artifact-nexus params START
         ## -h 
-        elif opt in ("-h", "--nexushost", "--awxhost"):
+        elif opt in ("-h", "--nexushost", "--awxhost", "--host"):
             if action == 'nexus':
                 repository_base_url = arg
                 if repository_base_url == '':
@@ -249,6 +272,8 @@ def main(argv):
                     return sys.exit(2)
             elif action == 'deploy':
                 url = arg
+            elif action == 'initialize':
+                sonarhost = arg
             else:
                 print("Invalid {} host specified".format(action))
                 return sys.exit(2)
@@ -284,11 +309,14 @@ def main(argv):
                     return sys.exit(2)
          
         ## -n  
-        elif opt in ("-n", "--artifactname"):
-            artifact_name = arg
-            if artifact_name == '':
-                print("Please specify artifact name")
-                return sys.exit(2)
+        elif opt in ("-n", "--artifactname", "--projectname"):
+            if action == 'initialize':
+                project_name = arg
+            else:
+                artifact_name = arg
+                if artifact_name == '':
+                    print("Please specify artifact name")
+                    return sys.exit(2)
         
         ## -g
         elif opt in ("-g", "--groupid"):
@@ -319,6 +347,14 @@ def main(argv):
         
         
         ## Commit-push changes repository END
+        
+        # Initialize START
+        elif opt in ("-l", "--language"):
+            language = arg
+            
+        elif opt in ("-k", "--projectkey"):
+            project_key = arg
+        # Initialize END       
          
     if debug == 1:
         print("Action entered: ", action)
@@ -347,9 +383,11 @@ def main(argv):
         #document artifact changes
         pass
     elif action == 'extract':
-        extract_commands.extract()
-        #pass    
-        #change_version.modify_version()        
+        extract_commands.extract()   
+    elif action == 'initialize':
+        #initialize.create_sonarq_project('test-frontend', 'goj-migration')   
+        initialize.setup_variables()
+        initialize.create_sonarq_project(project_name, project_key)
     elif action == '':
         print("Invalid action specified")
         return sys.exit(2)
