@@ -21,6 +21,8 @@ template_gitlab_ci = "variables:\n    GIT_STRATEGY: clone\n\n" \
                     "     #- <put production buildscript here>\n  only:\n    - master\n  tags:\n    - <runner>\n\n" \
                     "test-project:\n  stage: test\n  script:\n     - echo Peforming Test\n" \
                     "     #- <put test scripts here>\n  tags:\n    - <runner>\n\n" \
+                    "sonar-scan:\n  stage: test\n  script:\n     - echo Peforming SonarQube scan\n" \
+                    "     #- <sonar_qube_script>\n  tags:\n    - <runner>\n\n" \
                     "upload-project:\n  stage: upload\n  script:\n     - echo Uploading artifact to Nexus\n" \
                     "     #- python3 -m artify -c nexus -f <format> -n <artifact_name.zip/.war> -h <Nexus_repository_host>\n  tags:\n    - <runner>\n\n" \
                     "deploy-project:\n  stage: deploy\n  script:\n     - echo Deploying App to server\n" \
